@@ -82,20 +82,6 @@ using namespace Kontact;
 #include <grantleetheme/grantleethememanager.h>
 #include <grantleetheme/grantleetheme.h>
 
-#if QT_VERSION < QT_VERSION_CHECK(5,7,0)
-namespace QtPrivate {
-template <typename T> struct QAddConst { typedef const T Type; };
-}
-
-// this adds const to non-const objects (like std::as_const)
-template <typename T>
-Q_DECL_CONSTEXPR typename QtPrivate::QAddConst<T>::Type &qAsConst(T &t) Q_DECL_NOTHROW { return t; }
-// prevent rvalue arguments:
-template <typename T>
-void qAsConst(const T &&) Q_DECL_EQ_DELETE;
-#endif
-
-
 // Define the maximum time Kontact waits for KSycoca to become available.
 static const int KSYCOCA_WAIT_TIMEOUT = 10;
 
@@ -111,7 +97,7 @@ public:
     virtual int startServiceFor(const QString &serviceType,
                                 const QString &constraint = QString(),
                                 QString *error = nullptr, QString *dbusService = nullptr,
-                                int flags = 0) Q_DECL_OVERRIDE;
+                                int flags = 0) override;
 
     // We need to keep track of the plugins which are loaded, so pass a pointer
     // to the plugin list here. Be sure to reset it back to 0 with
@@ -159,7 +145,7 @@ int ServiceStarter::startServiceFor(const QString &serviceType,
 
 MainWindow::MainWindow()
     : KontactInterface::Core(), mSplitter(nullptr), mCurrentPlugin(nullptr), mAboutDialog(nullptr),
-      mReallyClose(false)
+    mReallyClose(false), mSaveSideBarWidth(10)
 {
     // The ServiceStarter created here will be deleted by the KDbusServiceStarter
     // base class, which is a global static.
@@ -251,10 +237,9 @@ void MainWindow::initObject()
                                 QStringLiteral("[X-KDE-KontactPluginVersion] == %1").arg(KONTACT_PLUGIN_VERSION));
     mPluginInfos = KPluginInfo::fromServices(
                        offers, KConfigGroup(Prefs::self()->config(), "Plugins"));
-    KPluginInfo::List::Iterator it;
-    KPluginInfo::List::Iterator end(mPluginInfos.end());
 
-    for (it = mPluginInfos.begin(); it != end; ++it) {
+    const KPluginInfo::List::Iterator end(mPluginInfos.end());
+    for (KPluginInfo::List::Iterator it = mPluginInfos.begin(); it != end; ++it) {
         it->load();
     }
 
@@ -361,15 +346,10 @@ void MainWindow::initWidgets()
     setCentralWidget(mTopWidget);
 
     mSplitter = new QSplitter(mTopWidget);
+    connect(mSplitter, &QSplitter::splitterMoved, this, &MainWindow::slotSplitterMoved);
     layout->addWidget(mSplitter);
     mSidePane = new IconSidePane(this, mSplitter);
-    /*
-    // don't occupy screen estate on load
 
-    QList<int> sizes;
-    sizes << 0;
-    mSplitter->setSizes(sizes);
-    */
     connect(mSidePane, SIGNAL(pluginSelected(KontactInterface::Plugin*)), SLOT(selectPlugin(KontactInterface::Plugin*)));
 
     mPartsStack = new QStackedWidget(mSplitter);
@@ -450,9 +430,15 @@ void MainWindow::setupActions()
     actionCollection()->addAction(QStringLiteral("help_introduction"), action);
     connect(action, &QAction::triggered, this, &MainWindow::slotShowIntroduction);
 
-    //TODO 4.12: add description
-    QShortcut *shortcut = new QShortcut(QKeySequence(Qt::Key_F9), this);
-    connect(shortcut, &QShortcut::activated, this, &MainWindow::slotShowHideSideBar);
+    mShowHideAction = new QAction(QIcon::fromTheme(QStringLiteral("zoom-fit-width")),
+                                  i18nc("@action:inmenu", "Hide/Show the component sidebar"), this);
+    setHelpText(mShowHideAction, i18nc("@info:status", "Hide/Show the component sidebar"));
+    mShowHideAction->setWhatsThis(
+        i18nc("@info:whatsthis",
+              "Allows you to show or hide the component sidebar as desired."));
+    mShowHideAction->setShortcut(QKeySequence(Qt::Key_F9));
+    actionCollection()->addAction(QStringLiteral("hide_show_sidebar"), mShowHideAction);
+    connect(mShowHideAction, &QAction::triggered, this, &MainWindow::slotShowHideSideBar);
 }
 
 bool MainWindow::isPluginLoaded(const KPluginInfo &info)
@@ -538,10 +524,9 @@ void MainWindow::loadPlugins()
         KontactInterface::Plugin *plugin = plugins.at(i);
 
         const QList<QAction *> actionList = plugin->newActions();
-        QList<QAction *>::const_iterator listIt;
         const QList<QAction *>::const_iterator end(actionList.end());
 
-        for (listIt = actionList.begin(); listIt != end; ++listIt) {
+        for (QList<QAction *>::const_iterator  listIt = actionList.begin(); listIt != end; ++listIt) {
             qCDebug(KONTACT_LOG) << QStringLiteral("Plugging New actions") << (*listIt)->objectName();
             mNewActions->addAction((*listIt));
         }
@@ -556,8 +541,7 @@ void MainWindow::loadPlugins()
 void MainWindow::unloadPlugins()
 {
     const KPluginInfo::List::ConstIterator end = mPluginInfos.constEnd();
-    KPluginInfo::List::ConstIterator it;
-    for (it = mPluginInfos.constBegin(); it != end; ++it) {
+    for (KPluginInfo::List::ConstIterator it = mPluginInfos.constBegin(); it != end; ++it) {
         if (!it->isPluginEnabled()) {
             removePlugin(*it);
         }
@@ -567,9 +551,8 @@ void MainWindow::unloadPlugins()
 void MainWindow::updateShortcuts()
 {
     const ActionPluginList::ConstIterator end = mActionPlugins.constEnd();
-    ActionPluginList::ConstIterator it;
     int i = 0;
-    for (it = mActionPlugins.constBegin(); it != end; ++it) {
+    for (ActionPluginList::ConstIterator it = mActionPlugins.constBegin(); it != end; ++it) {
         QAction *action = static_cast<QAction *>(*it);
         const QString shortcut = QStringLiteral("Ctrl+%1").arg(mActionPlugins.count() - i);
         actionCollection()->setDefaultShortcut(action, QKeySequence(shortcut));
@@ -870,18 +853,12 @@ void MainWindow::selectPlugin(const QString &pluginName)
 void MainWindow::loadSettings()
 {
     if (mSplitter) {
-        // if the preferences do not contain useful values, the side pane part of the splitter
-        // takes up the full width of the window, so leave the splitter sizing at the widget defaults
-        QList<int> sizes = Prefs::self()->sidePaneSplitter();
-        if (sizes.count() == mSplitter->count()) {
-            mSplitter->setSizes(sizes);
-        }
+        showHideSideBar(Prefs::self()->sideBarOpen());
     }
 
     // Preload Plugins. This _must_ happen before the default part is loaded
-    PluginList::ConstIterator it;
     PluginList::ConstIterator end(mDelayedPreload.constEnd());
-    for (it = mDelayedPreload.constBegin(); it != end; ++it) {
+    for (PluginList::ConstIterator it = mDelayedPreload.constBegin(); it != end; ++it) {
         selectPlugin(*it);
     }
     selectPlugin(Prefs::self()->mActivePlugin);
@@ -918,9 +895,8 @@ void MainWindow::slotPreferences()
 
         // do not show settings of components running standalone
         KPluginInfo::List filteredPlugins = mPluginInfos;
-        PluginList::ConstIterator it;
         PluginList::ConstIterator end(mPlugins.constEnd());
-        for (it = mPlugins.constBegin(); it != end; ++it) {
+        for (PluginList::ConstIterator it = mPlugins.constBegin(); it != end; ++it) {
             if ((*it)->isRunningStandalone()) {
                 KPluginInfo::List::ConstIterator infoIt;
                 KPluginInfo::List::ConstIterator infoEnd(filteredPlugins.constEnd());
@@ -1122,16 +1098,54 @@ QVariantHash MainWindow::introductionData()
     return data;
 }
 
+void MainWindow::showHideSideBar(bool show)
+{
+    QList<int> sizes = mSplitter->sizes();
+    if (!sizes.isEmpty()) {
+        if (show) {
+            sizes[0] = mSaveSideBarWidth;
+        } else {
+            mSaveSideBarWidth = qMax(sizes[0], 10);
+            sizes[0] = 0;
+        }
+        mSplitter->setSizes(sizes);
+        Prefs::self()->setSideBarOpen(show);
+    }
+}
+
+QString MainWindow::showHideSideBarMessage(bool hidden) const
+{
+    if (hidden) {
+        return i18nc("@info:status",
+                     "Sidebar is hidden. Show the sidebar again using the %1 key.",
+                     mShowHideAction->shortcut().toString());
+    } else {
+        return QString();
+    }
+}
+
 void MainWindow::slotShowHideSideBar()
 {
     QList<int> sizes = mSplitter->sizes();
     if (!sizes.isEmpty()) {
-        if (sizes.at(0) != 0) {
-            sizes[0] = 0;
+        bool open = (sizes.at(0) != 0);
+        showHideSideBar(!open);
+        if (open) {
+            statusBar()->showMessage(showHideSideBarMessage(true));
         } else {
-            sizes[0] = 10;
+            statusBar()->showMessage(showHideSideBarMessage(false));
+        }
+    }
+}
+
+void MainWindow::slotSplitterMoved(int pos, int index)
+{
+    if (index == 1) {
+        if (pos == 0) {
+            statusBar()->showMessage(showHideSideBarMessage(true));
+        } else {
+            statusBar()->showMessage(showHideSideBarMessage(false));
         }
-        mSplitter->setSizes(sizes);
     }
 }
 
